"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@oclif/core");
const util_1 = require("../lib/utils/util");
const path_1 = tslib_1.__importDefault(require("path"));
const fs_1 = tslib_1.__importDefault(require("fs"));
const fs_2 = require("../lib/utils/fs");
class GenDiffEnvNameType extends core_1.Command {
    run() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const { flags } = yield this.parse(GenDiffEnvNameType);
            const prev = (0, util_1.parseEnv)(flags['prev-env']);
            const after = (0, util_1.parseEnv)(flags['after-env']);
            const envNames = {};
            for (const [k] of Object.entries(after)) {
                // only print changed vars
                if (prev[k] !== after[k]) {
                    envNames[k] = k;
                }
            }
            const fileContent = `export const AllProjectDiffEnvNames = ${JSON.stringify(envNames, null, 2)} as const;
export type ProjectDiffEnvName = keyof typeof AllProjectDiffEnvNames;`;
            if (flags.output) {
                const tempstats = fs_1.default.statSync(flags.output);
                if (tempstats.isDirectory()) {
                    (0, fs_2.ensureDirSync)(flags.output);
                    const outputFilePath = path_1.default.join(flags.output, 'env.d.ts');
                    fs_1.default.writeFileSync(outputFilePath, fileContent);
                    console.log(`output file: ${outputFilePath}`);
                }
                else {
                    const folderPath = path_1.default.parse(flags.output);
                    (0, fs_2.ensureDirSync)(folderPath.dir);
                    fs_1.default.writeFileSync(flags.output, fileContent);
                    console.log(`output file: ${flags.output}`);
                }
            }
            else {
                console.log(fileContent);
            }
        });
    }
}
exports.default = GenDiffEnvNameType;
GenDiffEnvNameType.description = 'Generate diff env name type definition';
GenDiffEnvNameType.examples = [
    `$ typed-env diff-env-name -p "$(env)" -a "$(env)"`,
];
GenDiffEnvNameType.flags = {
    'prev-env': core_1.Flags.string({
        char: 'p',
        description: 'enter current env json',
        required: true,
    }),
    'after-env': core_1.Flags.string({
        char: 'a',
        description: 'enter change env json',
        required: true,
    }),
    output: core_1.Flags.string({
        char: 'o',
        description: 'enter the output file path',
    }),
};
